package dev.kske.chess;

import java.awt.Color;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.event.ComponentAdapter;
import java.awt.event.ComponentEvent;

import javax.swing.JPanel;

/**
 * Project: <strong>Chess</strong><br>
 * File: <strong>BoardPanel.java</strong><br>
 * Created: <strong>01.07.2019</strong><br>
 * Author: <strong>Kai S. K. Engelbart</strong><br>
 * <br>
 * A square panel for rendering the chess board. To work correctly,
 * this must be added to a parent component that allows the child to decide the
 * size.
 */
public class BoardPanel extends JPanel {

	private static final long serialVersionUID = 6771148331334310216L;

	private int tileSize;

	public BoardPanel() {
		// Add a component listener for adjusting the tile size on resizing
		addComponentListener(new ComponentAdapter() {

			@Override
			public void componentResized(ComponentEvent e) {
				tileSize = getWidth() / 8;
			}
		});
	}

	@Override
	protected void paintComponent(Graphics g) {
		super.paintComponent(g);
		g.setColor(Color.white);
		for (int i = 0; i < 8; i++)
			for (int j = 0; j < 8; j++) {
				if (j > 0) g.setColor(g.getColor().equals(Color.white) ? Color.black : Color.white);
				g.fillRect(tileSize * i, tileSize * j, tileSize, tileSize);
			}
	}

	@Override
	public Dimension getMinimumSize() { return getPreferredSize(); }

	@Override
	public Dimension getMaximumSize() { return getPreferredSize(); }

	@Override
	public Dimension getPreferredSize() {
		Dimension	d	= super.getPreferredSize();
		Container	c	= getParent();
		if (c != null) d = c.getSize();
		else return new Dimension(480, 480);
		int	w	= (int) d.getWidth();
		int	h	= (int) d.getHeight();
		int	s	= Math.max(w, h);
		return new Dimension(s, s);
	}
}
